==> fillets-ng-data-0.7.1.tar.gz: fillets-ng-data-0.7.1/script/atlantis/dialogs_it.lua <==

dialogId("sp-v-no0", "font_big", "Lo and behold!")
dialogStr("Ecco!")

dialogId("sp-m-no1", "font_small", "Just imagine!")
dialogStr("Impossibile!")

dialogId("sp-v-kdoby", "font_big", "Who could have guessed?!")
dialogStr("Chi poteva immaginarselo?!")

dialogId("sp-m-neopatrnost", "font_small", "Such carelessness.")
dialogStr("Che sbadataggine.")

dialogId("sp-v-zahynuli", "font_big", "Thousands perished - the whole city disappeared in the waves because of such ineptness.")
dialogStr("In migliaia sono morti, l'intera città è scomparsa, a causa di questa dimenticanza.")

dialogId("sp-m-vytazeny", "font_small", "Unplugged plug.")
dialogStr("Un tappo stappato.")

dialogId("sp-v-trapne", "font_big", "An embarrassing blunder.")
dialogStr("Una svista imbarazzante.")

dialogId("sp-m-costim", "font_small", "What are we to do with it?")
dialogStr("Che ci facciamo?")

dialogId("sp-v-vratit0", "font_big", "We can try to put it back in place.")
dialogStr("Possiamo provare a rimetterlo a posto.")

dialogId("sp-m-vratit0", "font_small", "And then? Shall we drink the water that poured in, or what?")
dialogStr("E dopo? Beviamo tutta l'acqua che si è riversata, o che?")

dialogId("sp-v-vratit1", "font_big", "We can put it back in place as a token of our esteem of the citizens` heroic effort to keep it afloat. As a memorial to their industrious, adroit and... persistent nature.")
dialogStr("Possiamo rimetterlo a posto come gesto di stima nei confronti degli eroici sforzi della cittadinanza per tenere la città a galla. A ricordo della loro industriosità, accortezza e... tenacia.")

dialogId("sp-m-vratit1", "font_small", "Of what? 'Where are you running? I need to order eight swords.` The Providence itself unplugged that hole. Just imagine you`d hear such things at home. Day by day.")
dialogStr("Di che? `Dove corri? A ordinare otto spade!' È la provvidenza ad aver tolto il tappo. Pensa se sentissi cose simili a casa tua. Ogni giorno.")

dialogId("sp-m-kalet", "font_small", "And moreover: is it likely that anybody would ever come here? Only sepias will nibble it occasionally.")
dialogStr("E poi, ti sembra che qualcuno tornerà mai qui? C'è solo qualche seppia che lo mordicchia ogni tanto.")

dialogId("sp-v-pocit", "font_big", "We are going to feel good about it.")
dialogStr("Sapremo di aver fatto una buona azione.")

dialogId("sp-m-potize", "font_small", "We are going to feel down about it. Do you think the boss is going to believe it? A giant unplugged plug? And what have you done with it? We plugged it again. He, he, he.")
dialogStr("Sapremo di aver fatto un'idiozia. Pensi che il capo ci crederà? Un grande tappo fuori posto? E voi cosa avete fatto? Lo abbiamo ritappato. Ah ah ah.")

dialogId("sp-v-vzit", "font_big", "You might be right. Maybe it would be better to take it along.")
dialogStr("Forse hai ragione. Forse sarebbe meglio portarcelo dietro.")

dialogId("sp-m-taky", "font_small", "I think so, too.")
dialogStr("Sono d'accordo.")

dialogId("sp-v-dotoho", "font_big", "Let `s get to work.")
dialogStr("Al lavoro.")

dialogId("sp-m-nechat", "font_small", "What if we just leave that plug here?")
dialogStr("Perché non lo lasciamo lì e basta?")

dialogId("sp-v-centrala", "font_big", "What would the Agency say?")
dialogStr("Cosa direbbe l'Agenzia?")

dialogId("sp-v-jedno", "font_big", "I don`t think I mind what the boss is going to think about me.")
dialogStr("Non me ne importa molto di cosa penserà il capo di me.")

dialogId("sp-m-vydrz", "font_small", "Hold on. We are sure to solve it.")
dialogStr("Forza. Lo risolveremo senz'altro.")

dialogId("sp-m-spunt", "font_small", "The darned plug. What if we just make up something.")
dialogStr("Dannato tappo. Potremmo inventarci qualcosa.")

dialogId("sp-v-co", "font_big", "Like what, for example?")
dialogStr("Tipo?")

dialogId("sp-m-vymluva0", "font_small", "Well, we could say that the city in fact never existed.")
dialogStr("Beh, potremmo dire che in realtà la città non è mai esistita.")

dialogId("sp-m-vymluva1", "font_small", "Well, we could say that the city sank because the Arctic ice had melted.")
dialogStr("Beh, potremmo dire che la città è stata sommersa a causa del discioglimento dei ghiacciai artici.")

dialogId("sp-m-vymluva2", "font_small", "An earthquake could have sunk the city, for example.")
dialogStr("Un terremoto potrebbe aver fatto affondare la città, per esempio.")

dialogId("sp-m-vymluva3", "font_small", "A tsunami might have sunk the city, for example.")
dialogStr("Ad esempio, uno tsunami potrebbe aver investito la città.")

dialogId("sp-m-vymluva4", "font_small", "We could try to say that a volcano erupted in the center of the city.")
dialogStr("Potremmo provare dicendo che un vulcano ha eruttato nel centro della città.")

dialogId("sp-v-nesmysl", "font_big", "That is just nonsense.")
dialogStr("Non ha senso.")

dialogId("sp-v-ven", "font_big", "This time our goal is to get that plug out.")
dialogStr("Questa volta il nostro compito è di portar fuori quel tappo.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/atlantis/dialogs_it.lua <==

dialogId("sp-v-no0", "font_big", "Lo and behold!")
dialogStr("Ecco!")

dialogId("sp-m-no1", "font_small", "Just imagine!")
dialogStr("Impossibile!")

dialogId("sp-v-kdoby", "font_big", "Who could have guessed?!")
dialogStr("Chi poteva immaginarselo?!")

dialogId("sp-m-neopatrnost", "font_small", "Such carelessness.")
dialogStr("Che sbadataggine.")

dialogId("sp-v-zahynuli", "font_big", "Thousands perished - the whole city disappeared in the waves because of such ineptness.")
dialogStr("In migliaia sono morti, l'intera città è scomparsa, a causa di questa dimenticanza.")

dialogId("sp-m-vytazeny", "font_small", "Unplugged plug.")
dialogStr("Un tappo stappato.")

dialogId("sp-v-trapne", "font_big", "An embarrassing blunder.")
dialogStr("Una svista imbarazzante.")

dialogId("sp-m-costim", "font_small", "What are we to do with it?")
dialogStr("Che ci facciamo?")

dialogId("sp-v-vratit0", "font_big", "We can try to put it back in place.")
dialogStr("Possiamo provare a rimetterlo a posto.")

dialogId("sp-m-vratit0", "font_small", "And then? Shall we drink the water that poured in, or what?")
dialogStr("E dopo? Beviamo tutta l'acqua che si è riversata, o che?")

dialogId("sp-v-vratit1", "font_big", "We can put it back in place as a token of our esteem of the citizens’ heroic effort to keep it afloat. As a memorial to their industrious, adroit and... persistent nature.")
dialogStr("Possiamo rimetterlo a posto come gesto di stima nei confronti degli eroici sforzi della cittadinanza per tenere la città a galla. A ricordo della loro industriosità, accortezza e... tenacia.")

dialogId("sp-m-vratit1", "font_small", "Of what? 'Where are you running? I need to order eight swords.’ The Providence itself unplugged that hole. Just imagine you’d hear such things at home. Day by day.")
dialogStr("Di che? ’Dove corri? A ordinare otto spade!' È la provvidenza ad aver tolto il tappo. Pensa se sentissi cose simili a casa tua. Ogni giorno.")

dialogId("sp-m-kalet", "font_small", "And moreover: is it likely that anybody would ever come here? Only sepias will nibble it occasionally.")
dialogStr("E poi, ti sembra che qualcuno tornerà mai qui? C'è solo qualche seppia che lo mordicchia ogni tanto.")

dialogId("sp-v-pocit", "font_big", "We are going to feel good about it.")
dialogStr("Sapremo di aver fatto una buona azione.")

dialogId("sp-m-potize", "font_small", "We are going to feel down about it. Do you think the boss is going to believe it? A giant unplugged plug? And what have you done with it? We plugged it again. He, he, he.")
dialogStr("Sapremo di aver fatto un'idiozia. Pensi che il capo ci crederà? Un grande tappo fuori posto? E voi cosa avete fatto? Lo abbiamo ritappato. Ah ah ah.")

dialogId("sp-v-vzit", "font_big", "You might be right. Maybe it would be better to take it along.")
dialogStr("Forse hai ragione. Forse sarebbe meglio portarcelo dietro.")

dialogId("sp-m-taky", "font_small", "I think so, too.")
dialogStr("Sono d'accordo.")

dialogId("sp-v-dotoho", "font_big", "Let ’s get to work.")
dialogStr("Al lavoro.")

dialogId("sp-m-nechat", "font_small", "What if we just leave that plug here?")
dialogStr("Perché non lo lasciamo lì e basta?")

dialogId("sp-v-centrala", "font_big", "What would the Agency say?")
dialogStr("Cosa direbbe l'Agenzia?")

dialogId("sp-v-jedno", "font_big", "I don’t think I mind what the boss is going to think about me.")
dialogStr("Non me ne importa molto di cosa penserà il capo di me.")

dialogId("sp-m-vydrz", "font_small", "Hold on. We are sure to solve it.")
dialogStr("Forza. Lo risolveremo senz'altro.")

dialogId("sp-m-spunt", "font_small", "The darned plug. What if we just make up something.")
dialogStr("Dannato tappo. Potremmo inventarci qualcosa.")

dialogId("sp-v-co", "font_big", "Like what, for example?")
dialogStr("Tipo?")

dialogId("sp-m-vymluva0", "font_small", "Well, we could say that the city in fact never existed.")
dialogStr("Beh, potremmo dire che in realtà la città non è mai esistita.")

dialogId("sp-m-vymluva1", "font_small", "Well, we could say that the city sank because the Arctic ice had melted.")
dialogStr("Beh, potremmo dire che la città è stata sommersa a causa del discioglimento dei ghiacciai artici.")

dialogId("sp-m-vymluva2", "font_small", "An earthquake could have sunk the city, for example.")
dialogStr("Un terremoto potrebbe aver fatto affondare la città, per esempio.")

dialogId("sp-m-vymluva3", "font_small", "A tsunami might have sunk the city, for example.")
dialogStr("Ad esempio, uno tsunami potrebbe aver investito la città.")

dialogId("sp-m-vymluva4", "font_small", "We could try to say that a volcano erupted in the center of the city.")
dialogStr("Potremmo provare dicendo che un vulcano ha eruttato nel centro della città.")

dialogId("sp-v-nesmysl", "font_big", "That is just nonsense.")
dialogStr("Non ha senso.")

dialogId("sp-v-ven", "font_big", "This time our goal is to get that plug out.")
dialogStr("Questa volta il nostro compito è di portar fuori quel tappo.")
